-- # select
SELECT id, name, create;
        
-- # from
FROM admins;

-- # where-find
WHERE id = ?;
    
-- # where-search
WHERE name LIKE ?;
    
-- # limit-find
LIMIT 1;
    
-- # limit-search
LIMIT ?, ?;
